@@ -1,4 +1,5 @@
-`networklevel` <- function(web, index="ALLBUTDD", level="both", weighted=TRUE, ISAmethod="Bluethgen", SAmethod="Bluethgen", extinctmethod="r", nrep=100, CCfun=median, dist="horn", normalise=TRUE, empty.web=TRUE, logbase="e", intereven="prod", H2_integer=TRUE, fcweighted=TRUE, fcdist="euclidean", effective=FALSE, legacy=FALSE){
+`networklevel` <- function(web, index="ALLBUTDD", level="both", weighted=TRUE, ISAmethod="Bluethgen", SAmethod="Bluethgen", extinctmethod="r", nrep=100, CCfun=median, dist="horn", normalise=TRUE, empty.web=TRUE, logbase="e", intereven="prod", H2_integer=TRUE, fcweighted=TRUE, fcdist="euclidean", effective=FALSE, legacy=FALSE, mass.action.norm=FALSE){
+
     ##
     ## web         interaction matrix, with lower trophic level in rows, higher in columns
     ## effective   logical; should interaction evenness, Alatalo evenness, H2', diversity be expressed as "effective" diversity; suggestion by Nico, 11.04.2024 = exp(SH)/prod(dim(web)) # e.g. Jost 2010 page 210
@@ -6,7 +7,7 @@
 #! JFedit: fddist and fdweighted replace throughout by fcdist and fcweighted
   
   ## !!!!! when adding a new index, make sure to also add it to the "exclude from grouplevel"-list !!!!!##
-  
+
   
   
     if(empty.web) {web <- empty(web)}
@@ -18,7 +19,7 @@
         #binary based and related:
         "links per species", "number of compartments", "compartment diversity",
         "cluster coefficient", "degree distribution", "mean number of shared partners",
-        "togetherness", "C score", "V ratio", "discrepancy", "nestedness", "NODF", "weighted nestedness",
+        "togetherness", "C score", "V ratio", "discrepancy", "nestedness", "NODF", "weighted nestedness", "spectral radius",
         #miscelleneous:
         "ISA", "SA", "extinction slope", "robustness", "niche overlap",   
         #quantitative series:
@@ -43,7 +44,7 @@
                         # logic: metrics for binary networks
                         "topology" = c("connectance", "cluster coefficient", "degree distribution", "togetherness", "nestedness", "NODF"),
                         # logic: more abstract, topological metrics for binary networks
-                        "networklevel" = c("connectance", "web asymmetry", "links per species", "number of compartments", "compartment diversity", "cluster coefficient", "modularity", "nestedness", "NODF", "weighted NODF", "ISA", "SA", "linkage density", "Fisher alpha", "diversity", "interaction evenness", "Alatalo interaction evenness", "H2"),
+                        "networklevel" = c("connectance", "web asymmetry", "links per species", "number of compartments", "compartment diversity", "cluster coefficient", "modularity", "nestedness", "NODF", "weighted NODF", "ISA", "SA", "linkage density", "Fisher alpha", "diversity", "interaction evenness", "Alatalo interaction evenness", "H2", "spectral radius"),
                         # only the truly networky indices
                         stop("Your index is not recognised! Typo? Check help for options!", call.=FALSE) #default for all non-matches
         )
@@ -148,6 +149,11 @@
             out$"weighted NODF" <- if (inherits(wNODF, "try-error")) NA else wNODF
         }
         #------------------
+        if ('spectral radius' %in% index) {
+          # The spectral radius is the largest Eigenvalue 
+          out$"spectral radius" <- spectral.radius(web, mass.action.norm)
+        }
+        #------------------
         if (any(c("ISA", "interaction strength asymmetry", "dependence asymmetry") %in% index)){
             # Dependence asymmetry (Bascompte et al. 2006; Bluethgen et al. 2007, Fig. S2)
             depL <- web.e/matrix(rowSums(web.e), nrow=NROW(web.e), ncol=NCOL(web.e), byrow=FALSE)
@@ -291,9 +297,10 @@
             H2 <- as.numeric(H2fun(web, H2_integer=H2_integer)[1]) #1.element is the standardised H2 prime
             out$"H2" <- if (effective) exp(max(0, H2)) else max(0, H2)
         }
+        
         #----------------------- now: grouplevel -------------------
         # a list of network indices (which should not be called through grouplevel):
-        netw.index <- match(c("connectance", "web asymmetry", "links per species", "number of compartments", "compartment diversity", "modularity", "nestedness", "NODF", "weighted nestedness", "weighted NODF", "ISA", "SA", "interaction evenness", "Alatalo interaction evenness", "Fisher alpha", "H2", "Shannon diversity", "linkage density", "weighted connectance"), index)
+        netw.index <- match(c("connectance", "web asymmetry", "links per species", "number of compartments", "compartment diversity", "modularity", "nestedness", "NODF", "weighted nestedness", "weighted NODF", "ISA", "SA", "interaction evenness", "Alatalo interaction evenness", "Fisher alpha", "H2", "Shannon diversity", "linkage density", "weighted connectance", "spectral radius"), index)
         exclude.index <- netw.index[!is.na(netw.index)]
         gindex <- if (length(exclude.index)==0) index else index[-exclude.index] # exclude NAs from this vector
         if (length(gindex) > 0) outg <- grouplevel(web, index=gindex, level=level, weighted=weighted, extinctmethod=extinctmethod, nrep=nrep, CCfun=CCfun, dist=dist, normalise=normalise, empty.web=empty.web, logbase=logbase, fcweighted=fcweighted, fcdist=fcdist)
